Accueil | Route 41
Date: 2015-12-01

Accueil - Route 41

### Bienvenue sur la plateforme de mobilité du Conseil départemental
de Loir-et-Cher

###

Sur cet espace vous pouvez :

- Gérer les inscriptions aux transports scolaires
- Consulter les horaires et circuits des transports scolaires et des lignes régulières
- Vous organiser pour covoiturer
- Obtenir des informations sur les transports à la demande
- Consulter le trafic sur les routes en temps réel
- Etre alerté en cas d'alerte météo et de mauvaises conditions de circulation

Une question, une remarque, un problème sur les routes ... ?
Contactez nous